import 'package:app_flowy/workspace/application/grid/cell/cell_service.dart';
import 'package:flowy_infra_ui/style_widget/hover.dart';
import 'package:flowy_sdk/protobuf/flowy-grid-data-model/grid.pb.dart' show FieldType;
import 'package:flutter/widgets.dart';
import 'checkbox_cell.dart';
import 'date_cell.dart';
import 'number_cell.dart';
import 'selection_cell/selection_cell.dart';
import 'text_cell.dart';

GridCellWidget buildGridCell(GridCellDataContext cellDataContext, {GridCellStyle? style}) {
  final key = ValueKey(cellDataContext.cellId);
  final fieldType = cellDataContext.cellData.field.fieldType;
  switch (fieldType) {
    case FieldType.Checkbox:
      return CheckboxCell(cellDataContext: cellDataContext, key: key);
    case FieldType.DateTime:
      return DateCell(cellDataContext: cellDataContext, key: key);
    case FieldType.MultiSelect:
      return MultiSelectCell(cellDataContext: cellDataContext, style: style, key: key);
    case FieldType.Number:
      return NumberCell(cellDataContext: cellDataContext, key: key);
    case FieldType.RichText:
      return GridTextCell(cellDataContext: cellDataContext, style: style, key: key);
    case FieldType.SingleSelect:
      return SingleSelectCell(cellDataContext: cellDataContext, style: style, key: key);
    default:
      throw UnimplementedError;
  }
}

class BlankCell extends StatelessWidget {
  const BlankCell({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Container();
  }
}

abstract class GridCellWidget extends HoverWidget {
  @override
  final ValueNotifier<bool> onFocus = ValueNotifier<bool>(false);
  GridCellWidget({Key? key}) : super(key: key);
}

abstract class GridCellStyle {}
